Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(720)

Unified Diff: net/spdy/spdy_test_util_common.h

Issue 2351513002: net: rename BoundNetLog to NetLogWithSource (Closed)
Patch Set: one more fix, content bound_net_log_ Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/spdy/spdy_test_util_common.h
diff --git a/net/spdy/spdy_test_util_common.h b/net/spdy/spdy_test_util_common.h
index 7d2a1bc25d66aabc59c344daaad3f6b3e7a3d418..2f3c290fbee02a1c76ac29c96be1636840f45bd2 100644
--- a/net/spdy/spdy_test_util_common.h
+++ b/net/spdy/spdy_test_util_common.h
@@ -40,7 +40,7 @@ class GURL;
namespace net {
-class BoundNetLog;
+class NetLogWithSource;
class CTVerifier;
class CTPolicyEnforcer;
class HostPortPair;
@@ -105,7 +105,7 @@ base::WeakPtr<SpdyStream> CreateStreamSynchronously(
const base::WeakPtr<SpdySession>& session,
const GURL& url,
RequestPriority priority,
- const BoundNetLog& net_log);
+ const NetLogWithSource& net_log);
// Helper class used by some tests to release a stream as soon as it's
// created.
@@ -221,7 +221,8 @@ class SpdyURLRequestContext : public URLRequestContext {
URLRequestContextStorage storage_;
};
// Equivalent to pool->GetIfExists(spdy_session_key, BoundNetLog()) != NULL.
bool HasSpdySession(SpdySessionPool* pool, const SpdySessionKey& key);
// Creates a SPDY session for the given key and puts it in the SPDY
@@ -230,7 +231,7 @@ bool HasSpdySession(SpdySessionPool* pool, const SpdySessionKey& key);
base::WeakPtr<SpdySession> CreateInsecureSpdySession(
HttpNetworkSession* http_session,
const SpdySessionKey& key,
- const BoundNetLog& net_log);
+ const NetLogWithSource& net_log);
// Tries to create a SPDY session for the given key but expects the
// attempt to fail with the given error. A SPDY session for |key| must
@@ -240,13 +241,13 @@ base::WeakPtr<SpdySession> TryCreateInsecureSpdySessionExpectingFailure(
HttpNetworkSession* http_session,
const SpdySessionKey& key,
Error expected_error,
- const BoundNetLog& net_log);
+ const NetLogWithSource& net_log);
// Like CreateInsecureSpdySession(), but uses TLS.
base::WeakPtr<SpdySession> CreateSecureSpdySession(
HttpNetworkSession* http_session,
const SpdySessionKey& key,
- const BoundNetLog& net_log);
+ const NetLogWithSource& net_log);
// Creates an insecure SPDY session for the given key and puts it in
// |pool|. The returned session will neither receive nor send any
@@ -221,7 +221,8 @@ class SpdyURLRequestContext : public URLRequestContext {
URLRequestContextStorage storage_;
};
-// Equivalent to pool->GetIfExists(spdy_session_key, BoundNetLog()) != NULL.
+// Equivalent to pool->GetIfExists(spdy_session_key, NetLogWithSource()) !=
+// NULL.
bool HasSpdySession(SpdySessionPool* pool, const SpdySessionKey& key);
// Creates a SPDY session for the given key and puts it in the SPDY

Powered by Google App Engine
This is Rietveld 408576698